from setuptools import setup, find_packages
import os

# قراءة README.md
with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

# قراءة requirements.txt
def read_requirements():
    if os.path.exists('requirements.txt'):
        with open('requirements.txt', 'r') as f:
            return [line.strip() for line in f if line.strip() and not line.startswith('#')]
    return []

setup(
    name="snow-dust",
    version='3.0.0',
    author="Samir Baladi",
    author_email="gitdeeper@gmail.com",
    description="Snow Dust: Advanced AI and Data Analysis Framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/gitdeeper1/snow-dust",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    python_requires=">=3.7",
    install_requires=read_requirements(),
)
